@@ -4,7 +4,7 @@ import gi
 import netifaces
 
 gi.require_version("Gtk", "3.0")
-from gi.repository import Gtk, Gdk, GLib, Pango
+from gi.repository import Gtk, GLib, Pango
 from ks_includes.screen_panel import ScreenPanel
 
 
@@ -19,7 +19,10 @@ class Panel(ScreenPanel):
         self.prev_network = None
         self.update_timeout = None
         self.network_interfaces = netifaces.interfaces()
-        self.wireless_interfaces = [iface for iface in self.network_interfaces if iface.startswith('w')]
+        self.wireless_interfaces = [
+            iface for iface in self.network_interfaces
+            if iface.startswith('wlan') or iface.startswith('wlp')
+        ]
         self.wifi = None
         self.use_network_manager = os.system('systemctl is-active --quiet NetworkManager.service') == 0
         if len(self.wireless_interfaces) > 0:
@@ -397,9 +400,24 @@ class Panel(ScreenPanel):
             chan = _("Channel") + f' {netinfo["channel"]}'
         if "signal_level_dBm" in netinfo:
             lvl = f'{netinfo["signal_level_dBm"]} ' + _("dBm")
+            if 'icon' not in self.labels['networks'][ssid]:
+                icon = self.signal_strength(int(netinfo["signal_level_dBm"]))
+                self.labels['networks'][ssid]['row'].add(icon)
+                self.labels['networks'][ssid]['row'].reorder_child(icon, 0)
+                self.labels['networks'][ssid]['icon'] = icon
 
         self.labels['networks'][ssid]['info'].set_markup(f"{info} <small>{encr}  {freq}  {chan}  {lvl}</small>")
-        self.labels['networks'][ssid]['info'].show_all()
+        self.labels['networks'][ssid]['row'].show_all()
+
+    def signal_strength(self, signal_level):
+        if signal_level > 50:
+            return self._gtk.Image('wifi_excellent')
+        elif signal_level > 60:
+            return self._gtk.Image('wifi_good')
+        elif signal_level > 70:
+            return self._gtk.Image('wifi_fair')
+        else:
+            return self._gtk.Image('wifi_weak')
 
     def update_single_network_info(self):
 
